import _extends from "@babel/runtime/helpers/esm/extends";
import React from 'react';
import cx from 'classnames';
import { CLASS, COLORS, DESIGNS, ICON_POSITIONS, GROUP_POSITIONS, MODIFIERS, OWN_PROPS, SIZES, TYPES } from './config';
import Button from './Button';
import ButtonIcon from './ButtonIcon';

var createClasses = function createClasses(array, sufix) {
  if (sufix === void 0) {
    sufix = '';
  }

  return array.reduce(function (res, key) {
    var _extends2;

    return _extends({}, res, (_extends2 = {}, _extends2[key] = CLASS + "--" + key + sufix, _extends2));
  }, {});
};

var CLASSES = createClasses([].concat(TYPES, Object.values(DESIGNS), MODIFIERS, Object.values(SIZES), ['empty']));
var COLOR_CLASSES = createClasses(COLORS, 'Color');
/**
 * Get props cleaning out AtomButton own props
 * @param  {Object} props
 * @return {Object}
 */

var cleanProps = function cleanProps(props) {
  var newProps = _extends({}, props);

  OWN_PROPS.forEach(function (key) {
    return delete newProps[key];
  });
  return newProps;
};
/**
 * Get modifiers to apply according to props
 * @param  {Object} props
 * @return {Array<String>}
 */


var getModifiers = function getModifiers(props) {
  return Object.keys(props).filter(function (name) {
    return props[name] && MODIFIERS.includes(name);
  });
};

var getPropsWithDefaultValues = function getPropsWithDefaultValues(props) {
  var color = props.color,
      design = props.design,
      type = props.type; // if color or design are defined, use them with the passed or default value

  if (color || design) {
    if (design !== DESIGNS.LINK) {
      color = color || 'primary';
    }

    design = design || 'solid';
  } else {
    type = type || 'primary';
  }

  return _extends({
    color: color,
    design: design,
    type: type
  }, props);
};

var AtomButton = function AtomButton(props) {
  var _getPropsWithDefaultV = getPropsWithDefaultValues(props),
      color = _getPropsWithDefaultV.color,
      children = _getPropsWithDefaultV.children,
      className = _getPropsWithDefaultV.className,
      focused = _getPropsWithDefaultV.focused,
      groupPosition = _getPropsWithDefaultV.groupPosition,
      leftIcon = _getPropsWithDefaultV.leftIcon,
      rightIcon = _getPropsWithDefaultV.rightIcon,
      size = _getPropsWithDefaultV.size,
      design = _getPropsWithDefaultV.design,
      title = _getPropsWithDefaultV.title,
      type = _getPropsWithDefaultV.type;

  var classNames = cx(CLASS, !type && COLOR_CLASSES[color], !type && CLASSES[design], type && CLASSES[type], groupPosition && CLASS + "-group " + CLASS + "-group--" + groupPosition, groupPosition && focused && CLASS + "-group--focused", size && CLASSES[size], getModifiers(props).map(function (key) {
    return CLASSES[key];
  }), !children && CLASSES.empty, className);
  var newProps = cleanProps(props);
  return /*#__PURE__*/React.createElement(Button, Object.assign({}, newProps, {
    className: classNames,
    title: title
  }), /*#__PURE__*/React.createElement("span", {
    className: CLASS + "-inner"
  }, /*#__PURE__*/React.createElement(ButtonIcon, {
    position: ICON_POSITIONS.LEFT,
    size: size
  }, leftIcon), leftIcon || rightIcon ? /*#__PURE__*/React.createElement("span", {
    className: CLASS + "-text"
  }, children) : children, /*#__PURE__*/React.createElement(ButtonIcon, {
    position: ICON_POSITIONS.RIGHT,
    size: size
  }, rightIcon)));
};

AtomButton.displayName = 'AtomButton';
export default AtomButton;
export { GROUP_POSITIONS as atomButtonGroupPositions };
export { COLORS as atomButtonColors };
export { DESIGNS as atomButtonDesigns };
export { SIZES as atomButtonSizes };
export { TYPES as atomButtonTypes };